/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_AUDIO_LOADERS_H
#define MYSDL_AUDIO_LOADERS_H

#include <ogg/ogg.h>
#include <vorbis/codec.h>
#include <vorbis/vorbisfile.h>

#include "../mysdl.h"

#include "core.h"

namespace mysdl
{
	namespace audio
	{
		extern const ALsizei DEF_BUFFER_SIZE;

		class FileLoader
		{
			protected:
				FILE *file;
				ALsizei format;
				ALsizei size;
				ALsizei frequency;

				ALsizei bufferSize;
				char *buffer;

			public:
				FileLoader(FILE *file,const std::string filename=""); // takes ownership of file
				virtual ~FileLoader();

				void freeBuffer();
				virtual char *read(ALsizei *bufferSize=0,bool loop=false)=0;
				virtual void rewind()=0;

				ALsizei getFormat();
				ALsizei getSize();
				ALsizei getFrequency();
		};

		class OggFileLoader : public FileLoader
		{
			protected:
				OggVorbis_File oggStream;
				vorbis_info *vorbisInfo;

			public:
				OggFileLoader(FILE *file,const std::string filename="");
				~OggFileLoader();

				void init(FILE *file);
				void rewind();

				char *read(ALsizei *bufferSize=0,bool loop=false);
		};

		FileLoader *getFileLoader(std::string filename);
	};
};

#endif
