/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_AUDIO_MUSIC_H
#define MYSDL_AUDIO_MUSIC_H

#include <list>

#include "SDL/SDL_thread.h"

#include "core.h"
#include "resources.h"
#include "sources.h"

namespace mysdl
{
	namespace audio
	{
		enum MusicManagerMode {mmmNormal=0,mmmFadeOut};
		const int BUFFERS_PER_STREAM=2;

		class MusicManager;

		class MusicStream
		{
			friend class MusicManager;

			protected:
				MusicManager *owner;
				const StreamedSample *sample;
				FileLoader *loader;
				ALsizei bufferSize;
				bool fileComplete;
				bool loop;
				ALuint buffers[BUFFERS_PER_STREAM];

				MusicStream(MusicManager *owner,StreamedSample *sample);
				~MusicStream();

				bool hasBuffer(ALuint buffer);
				bool stream(ALuint buffer,bool newStream);
		};

		class MusicManager
		{
			protected:
				bool stopped;

				ALuint sourceName;
				//Source *source;
				std::list<StreamedSample *> queue;
				StreamedSound *currentSound;

				bool running;
				SDL_Thread *thread;
				SDL_mutex *mutex;

				ALfloat volume,currentVolume;
				MusicManagerMode mode;
				ALfloat modeParam;
				bool currentStreamComplete;

				MusicStream *currentStream,*nextStream;

				void stream();

			public:
				MusicManager();
				virtual ~MusicManager();

				void skipToNext();
				void skipToLast();
				void addAsNext(StreamedSample *sample);
				void addAsLast(StreamedSample *sample);
				void clearQueue();

				void perform(Uint32 ticks);
				void play();
				void stop();

				int run(); //private
				int terminate();

				void setCurrentVolume(ALfloat volume);
				void setVolume(ALfloat volume);
				void fadeOut(Uint32 ticks);

				bool isPlaying();
		};
	};
};

#endif
