/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_GUI_CONTAINERS_H
#define MYSDL_GUI_CONTAINERS_H

#include <list>
#include <string>

#include "core.h"
#include "styles.h"

namespace mysdl
{
	namespace gui
	{
		/**
		 * A component with a rectangle style which is typically
		 * used as a container for other components.
		 */
		class Pane : public Component
		{
			protected:
				/** Style for the client area. */
				RectStyle *style;

			public:
				/**
				 * Creates a new pane.
				 */
				Pane();

				/**
				 * Draws the pane.
				 */
				void drawSelf();

				/**
				 * Reads the pane's properties from the specified DOM node.
				 * TODO: make private?
				 *
				 * @param node DOM node containing pane data.
				 * @param gui  TODO: ?
				 */
				void getSelfFromNode(const xml::Node *node,GUI *gui);

				/**
				 * Sets the style to be used for drawing the pane.
				 *
				 * @param style Style.
				 */
				void setStyle(RectStyle *style);

				/**
				 * Returns the style used for drawing the pane.
				 *
				 * @return Style.
				 */
				RectStyle *getStyle();
		};
	};
};

#endif
