/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_GUI_XML_H
#define MYSDL_GUI_XML_H

#include <list>
#include <string>

#include "core.h"

namespace mysdl
{
	namespace gui
	{
		// ================================================================
		//  XML constants for GUI components and properties
		// ================================================================

		const char *const XML_GUI_GUI="GUI";
		const char *const XML_GUI_DATA="data";
		const char *const XML_GUI_DATASTRING="dataString";
		const char *const XML_GUI_FONTS="fonts";
		const char *const XML_GUI_IMAGES="images";
		const char *const XML_GUI_PLAINRECTSTYLE="PlainRectStyle";
		const char *const XML_GUI_TEXTUREDRECTSTYLE="TexturedRectStyle";
		const char *const XML_GUI_SIMPLEFONTSTYLE="SimpleFontStyle";
		const char *const XML_GUI_LABELSTYLE="LabelStyle";
		const char *const XML_GUI_BUTTONSTYLE="ButtonStyle";
		const char *const XML_GUI_DROPDOWNLISTSTYLE="DropdownListStyle";
		const char *const XML_GUI_CHECKBOXSTYLE="CheckboxStyle";
		const char *const XML_GUI_PANE="Pane";
		const char *const XML_GUI_INPUTCAPTOR="InputCaptor";
		const char *const XML_GUI_LABEL="Label";
		const char *const XML_GUI_BUTTON="Button";
		const char *const XML_GUI_CHECKBOX="Checkbox";
		const char *const XML_GUI_DROPDOWNLIST="DropdownList";
		const char *const XML_GUI_TEXTFIELD="Textfield";
		const char *const XML_GUI_SLIDER_INT="Slider_int";
		const char *const XML_GUI_SLIDER_FLOAT="Slider_float";
		const char *const XML_GUI_ITEM="Item";
		const char *const XML_GUI_NAME="name";
		const char *const XML_GUI_VISIBLE="visible";
		const char *const XML_GUI_ENABLED="enabled";
		const char *const XML_GUI_X="x";
		const char *const XML_GUI_Y="y";
		const char *const XML_GUI_WIDTH="width";
		const char *const XML_GUI_HEIGHT="height";
		const char *const XML_GUI_GRID_X="gridX";
		const char *const XML_GUI_GRID_Y="gridY";
		const char *const XML_GUI_GRID_WIDTH="gridWidth";
		const char *const XML_GUI_GRID_HEIGHT="gridHeight";
		const char *const XML_GUI_CURSOR="cursor";
		const char *const XML_GUI_FONT="font";
		const char *const XML_GUI_FAMILY="family";
		const char *const XML_GUI_SIZE="size";
		const char *const XML_GUI_JUSTIFICATION_HORIZONTAL="horizontal";
		const char *const XML_GUI_JUSTIFICATION_VERTICAL="vertical";
		const char *const XML_GUI_IMAGE_HORIZONTAL="imageHorizontal";
		const char *const XML_GUI_IMAGE_VERTICAL="imageVertical";
		const char *const XML_GUI_COLOR="color";
		const char *const XML_GUI_IMAGECOLOR="imageColor";
		const char *const XML_GUI_COLORBORDER="colorBorder";
		const char *const XML_GUI_COLORBORDER1="colorBorder1";
		const char *const XML_GUI_COLORBORDER2="colorBorder2";
		const char *const XML_GUI_STYLE="style";
		const char *const XML_GUI_RECT="rect";
		const char *const XML_GUI_UP="up";
		const char *const XML_GUI_DOWN="down";
		const char *const XML_GUI_UPHOT="upHot";
		const char *const XML_GUI_DOWNHOT="downHot";
		const char *const XML_GUI_CHECKED="checked";
		const char *const XML_GUI_UNCHECKED="unchecked";
		const char *const XML_GUI_TRIGGER="trigger";
		const char *const XML_GUI_TRIGGER_ON="triggerOn";
		const char *const XML_GUI_TRIGGER_OFF="triggerOff";
		const char *const XML_GUI_TRIGGER_CONFIRM="triggerConfirm";
		const char *const XML_GUI_TRIGGER_KEY="triggerKey";
		const char *const XML_GUI_TRIGGER_JOYBUTTON="triggerJoyButton";
		const char *const XML_GUI_TRIGGER_JOYAXIS="triggerJoyAxis";
		const char *const XML_GUI_TRIGGER_NORTH="triggerNorth";
		const char *const XML_GUI_TRIGGER_EAST="triggerEast";
		const char *const XML_GUI_TRIGGER_SOUTH="triggerSouth";
		const char *const XML_GUI_TRIGGER_WEST="triggerWest";
		const char *const XML_GUI_CAPTION="caption";
		const char *const XML_GUI_IMAGE="image";
		const char *const XML_GUI_BORDER="border";
		const char *const XML_GUI_UPPERLEFT="upperLeft";
		const char *const XML_GUI_UPPER="upper";
		const char *const XML_GUI_UPPERRIGHT="upperRight";
		const char *const XML_GUI_LEFT="left";
		const char *const XML_GUI_CENTER="center";
		const char *const XML_GUI_RIGHT="right";
		const char *const XML_GUI_LOWERLEFT="lowerLeft";
		const char *const XML_GUI_LOWER="lower";
		const char *const XML_GUI_LOWERRIGHT="lowerRight";
		const char *const XML_GUI_STRETCH="stretch";
		const char *const XML_GUI_STRETCH_UPPER="stretchUpper";
		const char *const XML_GUI_STRETCH_LOWER="stretchLower";
		const char *const XML_GUI_STRETCH_LEFT="stretchLeft";
		const char *const XML_GUI_STRETCH_RIGHT="stretchRight";
		const char *const XML_GUI_STRETCH_CENTER="stretchCenter";
		const char *const XML_GUI_ID="id";
		const char *const XML_GUI_MIN="min";
		const char *const XML_GUI_MAX="max";
		const char *const XML_GUI_STEP_SMALL="stepSmall";
		const char *const XML_GUI_STEP_LARGE="stepLarge";
		const char *const XML_GUI_VALUE="value";
		const char *const XML_GUI_ORIENTATION="orientation";
		const char *const XML_GUI_BUTTONS_BEFORE="buttonsBefore";
		const char *const XML_GUI_BUTTONS_AFTER="buttonsAfter";
		const char *const XML_GUI_BAR_STYLE="barStyle";
		const char *const XML_GUI_HANDLE_STYLE="handleStyle";
		const char *const XML_GUI_BUTTON_STYLE="buttonStyle";
		const char *const XML_GUI_REPEAT="repeat";
	};
};

#endif
