/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_PARTICLES_EXPLOSIONS_H
#define MYSDL_PARTICLES_EXPLOSIONS_H

#include <vector>

#include "../mysdl.h"

#include "../gfx/images.h"

namespace mysdl
{
	namespace particles
	{
		class Explosion;
		class ExplosionParticle;

		class ExplosionProperties
		{
			public:
				Uint32 count;

				Vector2D speedFactor;
				Vector2D speedOffset;
				mysdl::gfx::Image *particleImage;
				GLfloat radius;

				Explosion *create() const;
		};

/*
		class ExplosionParticleEntry
		{
			public:
				Vector2D edge1;
				Color color1;
				Vector2D edge2;
				Color color2;
				Vector2D edge3;
				Color color3;
				Vector2D edge4;
				Color color4;
		};
*/
		class Explosion
		{
			public:
				ExplosionProperties properties;
				Vector2D pos;
				ExplosionParticle *particles;
				//ExplosionParticleEntry *array;
				GLfloat *array;
				Uint32 particleCount;
				Uint32 drawCount;

				Explosion(ExplosionProperties properties);
				~Explosion();

				void release();
				void init();
				void perform(GLfloat factor);
				void draw();
		};

		class ExplosionParticle
		{
			public:
				Vector2D pos;
				Color color;
				Vector2D velocity;
				Color colorVelocity;
				bool active;

				void perform(GLfloat ticks)
				{
					pos+=velocity*ticks;
					color+=colorVelocity*ticks;

					active=(color.a>0);
				}
		};
	};
};

#endif
