/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_PARTICLES_STARFIELD_H
#define MYSDL_PARTICLES_STARFIELD_H

#include <vector>

#include "../mysdl.h"

namespace mysdl
{
	namespace particles
	{
		class Star
		{
			public:
				Vector2D pos;
		};
		
		class StarClass
		{
			public:
				Uint32 count;
				GLfloat speed;
				Color color;
				
				StarClass(Uint32 count,GLfloat speed,Color color) :
					count(count),speed(speed),color(color)
				{
				}
		};

		class Starfield;
		
		class StarfieldProperties
		{
			public:
				Vector2D dimensions;
				std::vector<StarClass> classes;
				
				Starfield *create();
		};
		
		class Starfield
		{
			private:
				StarfieldProperties properties;
				Star *stars;
				Uint32 starCount;
				
			public:
				GLfloat speedFactor;
				
				Starfield(StarfieldProperties properties);
				~Starfield();
				
				void release();
				void init();
				void perform(GLfloat factor);
				void draw();
		};
	};
};

#endif
