/**
 * MySDL - A multimedia framework based on SDL and OpenGL
 * Copyright (C) 2006 Marian Schedenig (marian@musgit.com)
 * http://www.musgit.com/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MYSDL_TOOLS_H
#define MYSDL_TOOLS_H

#include <string>
#include <list>
#include <map>

#include "SDL/SDL.h"
#include "SDL/SDL_thread.h"

#include "debug.h"

namespace mysdl
{
  /**
   * Converts a frame delay value into a frames per second
   * rate.
   *
   * @param ticks Number of ticks between two frames.
   *
   * @returns Number of frames per second.
   */
  int calcFPS(int ticks);

  /**
   * Returns the number of ticks since the last call to this function. One
	 * tick represents one millisecond.
   * <p>
   * <b>Note:</b> The first call will return the number of ticks since the
   *              timer initialiation (typically the time at which the system
   *              was started). You should therefore make a dummy call to this
   *              function before using it for the first time.
   *
   * @return Number of ticks.
   */
  Uint32 getElapsedTicks();

	/**
	 * Returns the tick value representing the current system time.
	 *
	 * @return Ticks.
	 */
	Uint32 getCurrentTicks();
};

#endif
